function estimate = generateEstimate(mixture,mask,fs,fRange,winLength,winShift)

% generate signal estimate(s) from mask(s)
%
% Usage:
%
% estimate =
% generateEstimate(mixture,mask,fs,fRange,winLength,winShift);
%
% Input:
%   *mixture: column vector(s) of mixture signal (sample X channel)
%   *mask: binary mask(s) (frequency X time frame X channel)
%   fs: sampling frequency of signals 
%       (default: 16 kHz)
%   fRange: minimum and maximum values in Hz for gammatone center frequencies
%       (default: [50 fs/2])
%   winLength: window length for each time frame in seconds
%       (default: 0.02)
%   winShift: length of shift between frames in seconds
%       (default: 0.01)
%   * denotes required inputs
%
% Output:
%   estimate: the estimated target signal(s) (sample X channel)
%
% John Woodruff (woodruff.95@osu.edu)
% Primary code by ZZ Jin, adapted by DL Wang


% if arguments not provided, set to default values
if nargin < 3
    fs = 16000;
end
if nargin < 4
    fRange = [50 fs/2];
end
if nargin < 5
    winLength = .02;
end
if nargin < 6
    winShift = winLength/2;
end


% convert frame length and frame shift to number of samples
winLength = floor(winLength*fs);
winShift = floor(winShift*fs);

% ensure that mixture signal is correct shape
mixture = reshape(mixture,length(mixture),min(size(mixture)));

numChan = size(mixture,2);

estimate = zeros(length(mixture),numChan);
for chan = 1:numChan
    disp(['Computing estimated signal for channel ',num2str(chan)]);

    estimate(:,chan) = resynthesis(mixture(:,chan), mask(:,:,chan), fRange, winLength, winShift, fs);
end
